@@ -126,7 +126,12 @@ static auto translate(const char * line) -> int {
 	// oddly, missing /run/systemd is perfectly okay
 	std::rewind(timer);
 	std::rewind(service);
-	execlp("systemd-analyze", "systemd-analyze", "verify", "/dev/fd/3:input.timer", "/dev/fd/4:input.service", static_cast<const char *>(nullptr));
+	// TODO: roll back to straight execlp() if we ever bump past the systemd ≥ 236 requirement (this is 250); cf. #161
+	// execlp("systemd-analyze", "systemd-analyze", "verify", "/dev/fd/3:input.timer", "/dev/fd/4:input.service", static_cast<const char *>(nullptr));
+	execl("/bin/sh", "sh", "-c",
+	      "systemd-analyze --version 2>/dev/null |"
+	      "{ read -r _ v _ || v=0; [ \"$v\" -lt 250 ] || exec systemd-analyze verify /dev/fd/3:input.timer /dev/fd/4:input.service; }",
+	      static_cast<const char *>(nullptr));
 	return 0;
 }
 
@@ -218,7 +223,7 @@ static auto list(const char * cron_file, const char * user) -> int {
 	auto err = errno;
 
 	if(err == ENOENT)
-		return std::fprintf(stderr, "no crontab for %s\n", user), ENOENT;
+		return std::fprintf(stderr, "no crontab for %s\n", user), 1;
 
 	if(user != current_user)
 		return std::fprintf(stderr, "you can not display %s's crontab\n", user), 1;
@@ -515,7 +520,7 @@ static auto replace(const char * cron_file, const char * user, const char * file
 }
 
 
-enum class action_t { replace, list = 'l', remove = 'r', edit = 'e', show = 's', translate = 't', test = 'T', version = 'V' };
+enum class action_t : char { replace, list = 'l', remove = 'r', edit = 'e', show = 's', translate = 't', test = 'T', version = 'V' };
 
 #define USAGE                                                                               \
 	"usage:\n"                                                                                \
