@@ -47,12 +47,16 @@ int main(int argc, char *argv[]) {
 		case 'r':
 			file = fopen(crontab, "r");
 			if (file == NULL) {
-				if(errno == ENOENT) return ENOENT;
-				perror("Cannot open input file");
-				return 1;
+				if(errno == ENOENT) {
+					fprintf(stderr, "no crontab for %s\n", pw->pw_name);
+					return ENOENT;
+				} else {
+					perror("Cannot open input file");
+					return 1;
+				}
 			};
 			while(fgets(buffer, sizeof(buffer), file)) {
-				printf("%s", buffer);
+				fputs(buffer, stdout);
 			}
 			fclose(file);
 			break;
@@ -100,7 +104,7 @@ int main(int argc, char *argv[]) {
 			int lines=0;
 			while(fgets(buffer, sizeof(buffer), stdin)) {
 				lines++;
-				if (fprintf(file, "%s", buffer) < 0) {
+				if (fputs(buffer, file) < 0) {
 					perror("Cannot write to file");
 					fclose(file);
 					unlink(temp);
@@ -114,6 +118,7 @@ int main(int argc, char *argv[]) {
 			}
 			if (fclose(file)) {
 				perror("fclose");
+				unlink(temp);
 				return 1;
 			}
 			if (rename(temp,crontab)) {
